# This needs to be changed accordingly to the application for what tracker-miners is bundled,
# e.g. for gnome-books, it would be org.gnome.Books. For F39+ flatpaks, this is done
# in container.yaml cleanup-commands.
%if 0%{?flatpak}
%global domain_ontology org.gnome.FlatpakApp
%else
%global domain_ontology org.freedesktop
%endif

%global with_enca 1
%global with_libcue 1
%global with_totem_pl_parser 1

%if 0%{?rhel} || 0%{?flatpak}
%global with_enca 0
%global with_libcue 0
%if 0%{?rhel} >= 10
%global with_totem_pl_parser 0
%endif
%endif

%global tinysparql_version 3.9

%global systemd_units localsearch-3.service localsearch-control-3.service localsearch-writeback-3.service

# Exclude private libraries from autogenerated provides and requires
%global __provides_exclude_from ^%{_libdir}/localsearch-3.0/
%global __requires_exclude ^(libtracker-extract\.so|libextract-.*\.so|libwriteback-.*\.so)

%global tarball_version %%(echo %{version} | tr '~' '.')

Name:           localsearch
Version:        3.9.0
Release:        1%{?dist}
Summary:        Localsearch and metadata extractors

# The indexer is a mix of GPLv2 and LGPLv2+ code
License:        GPL-2.0-or-later AND LGPL-2.1-or-later
URL:            https://gnome.pages.gitlab.gnome.org/localsearch/
Source0:        https://download.gnome.org/sources/%{name}/3.9/%{name}-%{tarball_version}.tar.xz
Source1:        flatpak-fixup.sh

BuildRequires:  asciidoc
BuildRequires:  gcc
BuildRequires:  giflib-devel
BuildRequires:  meson
BuildRequires:  systemd-rpm-macros
BuildRequires:  pkgconfig(dbus-1)
%if 0%{?with_enca}
BuildRequires:  pkgconfig(enca)
%endif
BuildRequires:  pkgconfig(exempi-2.0)
BuildRequires:  pkgconfig(flac)
BuildRequires:  pkgconfig(gexiv2)
BuildRequires:  pkgconfig(gobject-introspection-1.0)
BuildRequires:  pkgconfig(gstreamer-1.0)
BuildRequires:  pkgconfig(gstreamer-pbutils-1.0)
BuildRequires:  pkgconfig(gstreamer-tag-1.0)
BuildRequires:  pkgconfig(icu-i18n)
BuildRequires:  pkgconfig(icu-uc)
BuildRequires:  pkgconfig(libavformat)
%if 0%{?with_libcue}
BuildRequires:  pkgconfig(libcue)
%endif
BuildRequires:  pkgconfig(libexif)
BuildRequires:  pkgconfig(libgsf-1)
BuildRequires:  pkgconfig(libgxps)
BuildRequires:  pkgconfig(libiptcdata)
BuildRequires:  pkgconfig(libjpeg)
BuildRequires:  pkgconfig(libpng)
BuildRequires:  pkgconfig(libseccomp)
BuildRequires:  pkgconfig(libtiff-4)
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(poppler-glib)
%if 0%{?with_totem_pl_parser}
BuildRequires:  pkgconfig(totem-plparser)
%endif
BuildRequires:  pkgconfig(tinysparql-3.0) >= %{tinysparql_version}
BuildRequires:  pkgconfig(vorbisfile)
%if !0%{?flatpak}
BuildRequires:  pkgconfig(libosinfo-1.0)
BuildRequires:  pkgconfig(libnm)
BuildRequires:  pkgconfig(upower-glib)
%endif

# renamed in F42
Obsoletes:      tracker-miners < 3.8
Provides:       tracker-miners = %{version}-%{release}
Provides:       tracker-miners%{?_isa} = %{version}-%{release}

%description
Tinysparql is a powerful desktop-neutral first class object database,
tag/metadata database and search tool.

This package contains various miners and metadata extractors for tinysparql.


%prep
%autosetup -p1 -n %{name}-%{tarball_version}


%build
%meson \
%if 0%{?flatpak}
  -Dwriteback=false \
  -Dsystemd_user_services=false \
  -Diso=disabled \
  -Dnetwork_manager=disabled \
  -Dbattery_detection=none \
  -Ddomain_prefix=%{domain_ontology} \
%endif
%if ! 0%{?with_libcue}
  -Dcue=disabled \
%endif
%if ! 0%{?flatpak}
  -Dsystemd_user_services_dir=%{_userunitdir} \
%endif
%if ! 0%{?with_totem_pl_parser}
  -Dplaylist=disabled \
%endif
  %{nil}

%meson_build


%install
%meson_install

%if 0%{?flatpak}
install -D -m 0755 %{SOURCE1} %{buildroot}%{_bindir}/%{name}-flatpak-fixup.sh
%endif

%find_lang localsearch3


%post
%systemd_user_post %{systemd_units}

%preun
%systemd_user_preun %{systemd_units}

%postun
%systemd_user_postun_with_restart %{systemd_units}


%files -f localsearch3.lang
%license COPYING*
%doc AUTHORS NEWS README.md
%config(noreplace) %{_sysconfdir}/xdg/autostart/localsearch-3.desktop
%{_bindir}/localsearch
%{_libdir}/localsearch-3.0/
%{_libexecdir}/localsearch-3
%{_libexecdir}/localsearch-control-3
%{_libexecdir}/localsearch-extractor-3
%{_libexecdir}/localsearch-writeback-3
%dir %{_datadir}/dbus-1
%dir %{_datadir}/dbus-1/interfaces
%dir %{_datadir}/dbus-1/services
%{_datadir}/dbus-1/interfaces/org.freedesktop.Tracker3.Miner.Files.Index.xml
%{_datadir}/dbus-1/interfaces/org.freedesktop.Tracker3.Miner.xml
%{_datadir}/dbus-1/services/org.freedesktop.Tracker3.Miner.Files.Control.service
%{_datadir}/dbus-1/services/org.freedesktop.Tracker3.Miner.Files.service
%{_datadir}/dbus-1/services/org.freedesktop.Tracker3.Writeback.service
%{_datadir}/dbus-1/services/%{domain_ontology}.LocalSearch*
%{_datadir}/glib-2.0/schemas/*
%{_datadir}/localsearch3/
%{_mandir}/man1/localsearch*.1*
%if !0%{?flatpak}
%{_userunitdir}/localsearch*.service
%endif
%if 0%{?flatpak}
%{_datadir}/localsearch3/domain-ontologies/%{domain_ontology}.domain.rule
%{_bindir}/%{name}-flatpak-fixup.sh
%endif


%changelog
* Thu Mar 20 2025 nmontero <nmontero@redhat.com> - 3.9.0-1
- Update to 3.9.0

* Wed Mar 05 2025 nmontero <nmontero@redhat.com> - 3.9~rc-1
- Update to 3.9.rc

* Mon Feb 24 2025 Nieves Montero <nmontero@redhat.com> - 3.8~rc-9
- Release bump

* Tue Feb 04 2025 Nieves Montero <nmontero@redhat.com> - 3.8~rc-8
- Bump the version of the tracker-miners obsoletes

* Wed Jan 29 2025 Nieves Montero <nmontero@redhat.com> - 3.8~rc-7
- Delete a Requires line

* Fri Jan 24 2025 Nieves Montero <nmontero@redhat.com> - 3.8~rc-6
- Change in Requires

* Mon Jan 20 2025 Fedora Release Engineering <releng@fedoraproject.org> - 3.8~rc-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_42_Mass_Rebuild

* Fri Jan 17 2025 Fedora Release Engineering <releng@fedoraproject.org> - 3.8~rc-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_42_Mass_Rebuild

* Fri Jan 17 2025 Nieves Montero <nmontero@redhat.com> - 3.8.rc-3
-Add gcc patch

* Wed Jan 15 2025 Nieves Montero <nmontero@redhat.com> - 3.8.rc-2
-Bump release to rebuild after deleted build

* Wed Nov 06 2024 Nieves Montero <nmontero@redhat.com> - 3.8.rc-1
- Rename tracker-miners to localsearch
- Update to 3.8~rc